@@ -41,16 +41,22 @@ class APIResponse(object):
         self.default_custom_asserter_list = default_custom_asserter_list
         self.custom_asserter_list = custom_asserter_list
 
+        self.error = []
+
         self._api_assert()
 
         AllureAttach.record_http(
             response=self.response, validators=self.validators, description=description, path=path
         )
+        self._raise_error()
         self.raise_failure()
 
     def _init_json(self):
         if not self.response_json:
-            self.response_json = self.json()
+            try:
+                self.response_json = self.json()
+            except Exception:
+                self._set_error('JSONDecodeError', self.response.request.url + '\n' + self.text)
         if not self.default_json_extraction:
             self.extraction_json = self.response_json
         else:
@@ -86,6 +92,34 @@ class APIResponse(object):
         if error_str:
             raise JsonAssertError('JSON 断言失败' + error_str)
 
+    def _set_error(self, error_type: str, error_msg: str):
+        """
+        设置异常信息
+        :param error_type:
+        :param error_msg:
+        :return:
+        """
+        error = {
+            'error_type': error_type,
+            'error_msg': error_msg,
+        }
+        self.error.append(error)
+
+    def _raise_error(self):
+        """
+
+        :return:
+        """
+        if self.error:
+            # from rich.table import Table
+            # table = Table(header_style="bold magenta")
+            # table.add_column("error_type", style="dim", width=12)
+            # table.add_column("error_msg")
+            for i in self.error:
+                error = i.get('error_type') + i.get('error_msg')
+                # table.add_row(i.get('error_type'), i.get('error_msg'))
+                raise Exception(error)
+
     def get_extraction_json(self) -> dict:
         """
         获取提取后的json数据
@@ -112,3 +146,32 @@ class APIResponse(object):
         return tuple(extraction_list)
 
 
+if __name__ == '__main__':
+    def raise_error():
+        """
+
+        :return:
+        """
+        error = [
+            {
+                'error_type': 'error_type',
+                'error_msg': 'error_msg',
+            }
+        ]
+        from rich.table import Table
+        table = Table(header_style="bold magenta")
+        table.add_column("error_type", style="dim", width=12)
+        table.add_column("error_msg")
+        for i in error:
+            table.add_row(i.get('error_type'), i.get('error_msg'))
+        # from rich import print
+        print(table.box)
+        print(table.columns)
+        # print(table)
+
+
+    """
+    https://www.jianshu.com/p/890f166f3e8f?utm_campaign=maleskine&utm_content=note&utm_medium=seo_notes
+    """
+
+    raise_error()
